aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/SyncPlay/SendCommandType.cs
diff options
context:
space:
mode:
authorIonut Andrei Oanca <oancaionutandrei@gmail.com>2020-09-24 23:04:21 +0200
committerIonut Andrei Oanca <oancaionutandrei@gmail.com>2020-10-16 12:06:29 +0200
commit8819a9d478e6fc11dbfdcff80d9a2dc175953373 (patch)
tree8a159745dd08ebfa6d83e881c8eb6a07df0a589d /MediaBrowser.Model/SyncPlay/SendCommandType.cs
parented2eabec16aafdf795f5ea4f8834ffdc74bc149f (diff)
Add playlist-sync and group-wait to SyncPlay
Diffstat (limited to 'MediaBrowser.Model/SyncPlay/SendCommandType.cs')
-rw-r--r--MediaBrowser.Model/SyncPlay/SendCommandType.cs11
1 files changed, 8 insertions, 3 deletions
diff --git a/MediaBrowser.Model/SyncPlay/SendCommandType.cs b/MediaBrowser.Model/SyncPlay/SendCommandType.cs
index 86dec9e90..e6b17c60a 100644
--- a/MediaBrowser.Model/SyncPlay/SendCommandType.cs
+++ b/MediaBrowser.Model/SyncPlay/SendCommandType.cs
@@ -6,9 +6,9 @@ namespace MediaBrowser.Model.SyncPlay
public enum SendCommandType
{
/// <summary>
/// The play command. Instructs users to start playback.
/// </summary>
- Play = 0,
+ Unpause = 0,
/// <summary>
/// The pause command. Instructs users to pause playback.
@@ -16,8 +16,13 @@ namespace MediaBrowser.Model.SyncPlay
Pause = 1,
/// <summary>
+ /// The stop command. Instructs users to stop playback.
+ /// </summary>
+ Stop = 2,
+
+ /// <summary>
/// The seek command. Instructs users to seek to a specified time.
/// </summary>
- Seek = 2
+ Seek = 3
}
}
@@ -6,9 +6,9 @@ namespace MediaBrowser.Model.SyncPlay
{
/// <summary>
- /// The play command. Instructs users to start playback.
+ /// The unpause command. Instructs users to unpause playback.
/// </summary>